<?php

namespace Assetdocs\Store\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Store\Http\Requests\SubstoreAdminApiRequest;
use Assetdocs\Store\Interfaces\SubstoreRepositoryInterface;
use Assetdocs\Store\Models\Substore;

/**
 * Admin API controller class.
 */
class SubstoreAdminApiController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.api';

    /**
     * Initialize substore controller.
     *
     * @param type SubstoreRepositoryInterface $substore
     *
     * @return type
     */
    public function __construct(SubstoreRepositoryInterface $substore)
    {
        $this->middleware('api');
        $this->middleware('jwt.auth:admin.api');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $substore;
        parent::__construct();
    }

    /**
     * Display a list of substore.
     *
     * @return json
     */
    public function index(SubstoreAdminApiRequest $request)
    {
        $substores  = $this->repository
            ->pushCriteria(new \Assetdocs\Store\Repositories\Criteria\SubstoreAdminCriteria())
            ->setPresenter('\\Assetdocs\\Store\\Repositories\\Presenter\\SubstoreListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $substores['code'] = 2000;
        return response()->json($substores) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display substore.
     *
     * @param Request $request
     * @param Model   Substore
     *
     * @return Json
     */
    public function show(SubstoreAdminApiRequest $request, Substore $substore)
    {
        $substore         = $substore->presenter();
        $substore['code'] = 2001;
        return response()->json($substore)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new substore.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(SubstoreAdminApiRequest $request, Substore $substore)
    {
        $substore         = $substore->presenter();
        $substore['code'] = 2002;
        return response()->json($substore)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new substore.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(SubstoreAdminApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $substore          = $this->repository->create($attributes);
            $substore          = $substore->presenter();
            $substore['code']  = 2004;

            return response()->json($substore)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
;
        }
    }

    /**
     * Show substore for editing.
     *
     * @param Request $request
     * @param Model   $substore
     *
     * @return json
     */
    public function edit(SubstoreAdminApiRequest $request, Substore $substore)
    {
        $substore         = $substore->presenter();
        $substore['code'] = 2003;
        return response()-> json($substore)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the substore.
     *
     * @param Request $request
     * @param Model   $substore
     *
     * @return json
     */
    public function update(SubstoreAdminApiRequest $request, Substore $substore)
    {
        try {

            $attributes = $request->all();

            $substore->update($attributes);
            $substore         = $substore->presenter();
            $substore['code'] = 2005;

            return response()->json($substore)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the substore.
     *
     * @param Request $request
     * @param Model   $substore
     *
     * @return json
     */
    public function destroy(SubstoreAdminApiRequest $request, Substore $substore)
    {

        try {

            $t = $substore->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('store::substore.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
