<?php

namespace Assetdocs\Store\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Store\Http\Requests\SubstoreAdminWebRequest;
use Assetdocs\Store\Interfaces\SubstoreRepositoryInterface;
use Assetdocs\Store\Models\Substore;

/**
 * Admin web controller class.
 */
class SubstoreAdminController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.web';

    /**
     * Initialize substore controller.
     *
     * @param type SubstoreRepositoryInterface $substore
     *
     * @return type
     */
    public function __construct(SubstoreRepositoryInterface $substore)
    {
        $this->middleware('web');
        $this->middleware('auth:admin.web');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $substore;
        parent::__construct();
    }

    /**
     * Display a list of substore.
     *
     * @return Response
     */
    public function index(SubstoreAdminWebRequest $request)
    {
        $pageLimit = $request->input('pageLimit');
        if ($request->wantsJson()) {
            $substores  = $this->repository
            ->pushCriteria(new \Assetdocs\Store\Repositories\Criteria\SubstoreAdminCriteria())
                ->setPresenter('\\Assetdocs\\Store\\Repositories\\Presenter\\SubstoreListPresenter')
                ->scopeQuery(function ($query) {
                    return $query->orderBy('id', 'DESC');
                })->paginate($pageLimit);

            $substores['recordsTotal']    = $substores['meta']['pagination']['total'];
            $substores['recordsFiltered'] = $substores['meta']['pagination']['total'];
            $substores['request']         = $request->all();
            return response()->json($substores, 200);

        }

        $this   ->theme->prependTitle(trans('store::substore.names').' :: ');
        return $this->theme->of('store::admin.substore.index')->render();
    }

    /**
     * Display substore.
     *
     * @param Request $request
     * @param Model   $substore
     *
     * @return Response
     */
    public function show(SubstoreAdminWebRequest $request, Substore $substore)
    {
        if (!$substore->exists) {
            return response()->view('store::admin.substore.new', compact('substore'));
        }

        Form::populate($substore);
        return response()->view('store::admin.substore.show', compact('substore'));
    }

    /**
     * Show the form for creating a new substore.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(SubstoreAdminWebRequest $request)
    {

        $substore = $this->repository->newInstance([]);

        Form::populate($substore);

        return response()->view('store::admin.substore.create', compact('substore'));

    }

    /**
     * Create new substore.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SubstoreAdminWebRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $substore          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('store::substore.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/store/substore/'.$substore->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show substore for editing.
     *
     * @param Request $request
     * @param Model   $substore
     *
     * @return Response
     */
    public function edit(SubstoreAdminWebRequest $request, Substore $substore)
    {
        Form::populate($substore);
        return  response()->view('store::admin.substore.edit', compact('substore'));
    }

    /**
     * Update the substore.
     *
     * @param Request $request
     * @param Model   $substore
     *
     * @return Response
     */
    public function update(SubstoreAdminWebRequest $request, Substore $substore)
    {
        try {

            $attributes = $request->all();

            $substore->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('store::substore.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/store/substore/'.$substore->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/store/substore/'.$substore->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the substore.
     *
     * @param Model   $substore
     *
     * @return Response
     */
    public function destroy(SubstoreAdminWebRequest $request, Substore $substore)
    {

        try {

            $t = $substore->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('store::substore.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/store/substore/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/store/substore/'.$substore->getRouteKey()),
            ], 400);
        }
    }
}
