<?php

namespace Assetdocs\Store\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Store\Http\Requests\SubstoreUserWebRequest;
use Assetdocs\Store\Interfaces\SubstoreRepositoryInterface;
use Assetdocs\Store\Models\Substore;

class SubstoreUserController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'web';

    /**
     * Initialize substore controller.
     *
     * @param type SubstoreRepositoryInterface $substore
     *
     * @return type
     */
    public function __construct(SubstoreRepositoryInterface $substore)
    {
        $this->middleware('web');
        $this->middleware('auth:web');
        $this->setupTheme(config('theme.themes.user.theme'), config('theme.themes.user.layout'));

        $this->repository = $substore;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(SubstoreUserWebRequest $request)
    {
        $this->repository->pushCriteria(new \Assetdocs\Store\Repositories\Criteria\SubstoreUserCriteria());
        $substores = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('store::substore.names').' :: ');

        return $this->theme->of('store::user.substore.index', compact('substores'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Substore $substore
     *
     * @return Response
     */
    public function show(SubstoreUserWebRequest $request, Substore $substore)
    {
        Form::populate($substore);

        return $this->theme->of('store::user.substore.show', compact('substore'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(SubstoreUserWebRequest $request)
    {

        $substore = $this->repository->newInstance([]);
        Form::populate($substore);

        return $this->theme->of('store::user.substore.create', compact('substore'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SubstoreUserWebRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $substore = $this->repository->create($attributes);

            return redirect(trans_url('/user/store/substore'))
                -> with('message', trans('messages.success.created', ['Module' => trans('store::substore.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Substore $substore
     *
     * @return Response
     */
    public function edit(SubstoreUserWebRequest $request, Substore $substore)
    {

        Form::populate($substore);

        return $this->theme->of('store::user.substore.edit', compact('substore'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Substore $substore
     *
     * @return Response
     */
    public function update(SubstoreUserWebRequest $request, Substore $substore)
    {
        try {
            $this->repository->update($request->all(), $substore->getRouteKey());

            return redirect(trans_url('/user/store/substore'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('store::substore.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(SubstoreUserWebRequest $request, Substore $substore)
    {
        try {
            $this->repository->delete($substore->getRouteKey());
            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('store::substore.name')]),
                'code'     => 202,
                'redirect' => trans_url('/user/store/substore/0'),
            ], 202);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
